# coding: utf-8

"""
    Graph API

     Module containing a class for interacting with the Graph API.   # noqa: E501
"""

from setuptools import setup, find_packages  # noqa: H301

NAME="graph_api"
VERSION='0.1.0'
REQUIRES=[
    'msal==1.16.0'
]

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

setup(
    name=NAME,
    version=VERSION,
    description="Active Directory",
    author="Pearson Service Insights",
    author_email="TOIOServiceWorkflowAutomation@grp.pearson.com",
    url="https://gitlab.com/pearson-io-swa/integrations",
    keywords=["Pearson", "PCM", "PSI", "Active Directory", "Graph"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
     Module containing a class for interacting with the Active Directory.   # noqa: E501
    """
)
